@@ -95,8 +95,8 @@ def find_measurable_max(fgraph: FunctionGraph, node: Apply) -> list[TensorVariab
         return None
 
     # univariate i.i.d. test which also rules out other distributions
-    for params in base_var.owner.inputs[3:]:
-        if params.type.ndim != 0:
+    for params in base_var.owner.op.dist_params(base_var.owner):
+        if not all(params.type.broadcastable):
             return None
 
     # Check whether axis covers all dimensions
@@ -107,7 +107,7 @@ def find_measurable_max(fgraph: FunctionGraph, node: Apply) -> list[TensorVariab
 
     # distinguish measurable discrete and continuous (because logprob is different)
     measurable_max: Max
-    if base_var.owner.op.dtype.startswith("int"):
+    if base_var.type.dtype.startswith("int"):
         measurable_max = MeasurableMaxDiscrete(list(axis))
     else:
         measurable_max = MeasurableMax(list(axis))
@@ -202,8 +202,8 @@ def find_measurable_max_neg(fgraph: FunctionGraph, node: Apply) -> list[TensorVa
         return None
 
     # univariate i.i.d. test which also rules out other distributions
-    for params in base_rv.owner.inputs[3:]:
-        if params.type.ndim != 0:
+    for params in base_rv.owner.op.dist_params(base_rv.owner):
+        if not all(params.type.broadcastable):
             return None
 
     # Check whether axis is supported or not
@@ -217,7 +217,7 @@ def find_measurable_max_neg(fgraph: FunctionGraph, node: Apply) -> list[TensorVa
 
     # distinguish measurable discrete and continuous (because logprob is different)
     measurable_min: Max
-    if base_rv.owner.op.dtype.startswith("int"):
+    if base_rv.type.dtype.startswith("int"):
         measurable_min = MeasurableDiscreteMaxNeg(list(axis))
     else:
         measurable_min = MeasurableMaxNeg(list(axis))
