@@ -1,4 +1,4 @@
-#   Copyright 2023 The PyMC Developers
+#   Copyright 2024 The PyMC Developers
 #
 #   Licensed under the Apache License, Version 2.0 (the "License");
 #   you may not use this file except in compliance with the License.
@@ -101,12 +101,10 @@ class QuadPotential:
     dtype: np.dtype
 
     @overload
-    def velocity(self, x: np.ndarray, out: None) -> np.ndarray:
-        ...
+    def velocity(self, x: np.ndarray, out: None) -> np.ndarray: ...
 
     @overload
-    def velocity(self, x: np.ndarray, out: np.ndarray) -> None:
-        ...
+    def velocity(self, x: np.ndarray, out: np.ndarray) -> None: ...
 
     def velocity(self, x: np.ndarray, out: np.ndarray | None = None) -> np.ndarray | None:
         """Compute the current velocity at a position in parameter space."""
