@@ -1,4 +1,4 @@
-#   Copyright 2023 The PyMC Developers
+#   Copyright 2024 The PyMC Developers
 #
 #   Licensed under the Apache License, Version 2.0 (the "License");
 #   you may not use this file except in compliance with the License.
@@ -76,7 +76,7 @@ def test_convert_outer_out_to_in_sit_sot():
     This should be a single SIT-SOT replacement.
     """
 
-    rng_state = np.random.RandomState(np.random.MT19937(np.random.SeedSequence(1234)))
+    rng_state = np.random.default_rng(123)
     rng_tt = pytensor.shared(rng_state, name="rng", borrow=True)
     rng_tt.tag.is_rng = True
     rng_tt.default_update = rng_tt
